Examples to go here

Puppy

 - Complex example based on Dagu playful puppy - specifically
   allows said device to be programmed in (a) python (subset)

servo

 - Test case really that shows how to use servos, however also quite a useful example

#include <Servo.h>

myservo = Servo()
pos = 0
pin=11

myservo_attach
myservo_attach(pin)



['function_call',
 ['identifier', 9, 'myservo_attach'],
 ['expression_list', [['identifier', 9, 'pin']]]]]]]]

 ['function_call',
 ['func_objref', 9, '['attributeaccess', ['identifier', 8, 'myservo'], ['attribute', 8, ['identifier', 8, 'attach']]]'],
 ['expression_list', [['identifier', 9, 'pin']]]]]]]]
